Skip to contents

Wrapper function for simulations with package medfate or medfateland

Usage

medfate2forestindicators(x, id_stand = NA, type = "plant_dynamic_input")

Arguments

x

An object issued from simulations with functions fordyn, fordyn_spatial, fordyn_scenario or fordyn_land

id_stand

A string identifying the forest stand (if x has been obtained using fordyn).

type

A string describing the input data frame for forestindicators.

Value

A data frame with data structure suitable for forestindicators