Wrapper function for simulations with package medfate or medfateland
Source:R/medfate2forestindicators.R
medfate2forestindicators.RdWrapper function for simulations with package medfate or medfateland
Arguments
- x
An object issued from simulations with functions
fordyn,fordyn_spatial,fordyn_scenarioorfordyn_land- id_stand
A string identifying the forest stand (if
xhas been obtained usingfordyn).- type
A string describing the input data frame for forestindicators.